.luckysheet_info_detail {
    height: 0 !important;
    overflow: hidden !important;
    margin: 0;
    padding: 0;
}

.luckysheet {
    position: absolute;
    font-size: 12px;
    font-family: sans-serif !important;
    border: 1px solid #e5e5e5;
    background: #fff;
}

.excel-icon {
    padding: 3px;
}

.excel-icon:hover {
    filter: brightness(1.1);
    background: #c4c3c3;
}