
#####################################################
# DO NOT MODIFY
# This file is used to define the remote assets
#####################################################
        
js_dist = [
  {
    "relative_package_path": "assets/plugin.js",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/plugins/js/plugin.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckysheet.umd.js",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/luckysheet.umd.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckysheet.umd.js.map",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/luckysheet.umd.js.map",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/luckyexcel.umd.js",
    "external_url": "https://cdn.jsdelivr.net/npm/luckyexcel/dist/luckyexcel.umd.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckyexcel.umd.js.map",
    "external_url": "https://cdn.jsdelivr.net/npm/luckyexcel/dist/luckyexcel.umd.js.map",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/exceljs.min.js",
    "external_url": "https://cdn.jsdelivr.net/npm/exceljs/dist/exceljs.min.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/exceljs.min.js.map",
    "external_url": "https://cdn.jsdelivr.net/npm/exceljs/dist/exceljs.min.js.map",
    "namespace": "dash_luckysheet",
    "dynamic": True
  }
]

css_dist = [
  {
    "relative_package_path": "assets/pluginsCss.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/plugins/css/pluginsCss.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/plugins.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/plugins/plugins.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckysheet.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/css/luckysheet.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/iconfont.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/assets/iconfont/iconfont.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/loading.gif",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/css/loading.gif",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/EwaAntH.gif",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/css/EwaAntH.gif",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/EwaAntV.gif",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/css/EwaAntV.gif",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/waffle_sprite.png",
    "external_url": "https://mengshukeji.github.io/LuckysheetDemo/css/waffle_sprite.png",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/icon_dropCell.png",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/plugins/images/icon_dropCell.png",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "fonts/fontawesome-webfont.woff2",
    "external_url": "https://github.com/h5p/font-awesome/raw/master/fontawesome-webfont.woff2",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "fonts/fontawesome-webfont.woff",
    "external_url": "https://github.com/h5p/font-awesome/raw/master/fontawesome-webfont.woff",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "fonts/fontawesome-webfont.ttf",
    "external_url": "https://github.com/h5p/font-awesome/raw/master/fontawesome-webfont.ttf",
    "namespace": "dash_luckysheet",
    "dynamic": True
  }
]